@@ -14,25 +14,25 @@
 # limitations under the License.
 
 from oslo_config import cfg
+import six
 
 import sahara.exceptions as e
 from sahara.i18n import _
+from sahara.service.edp.job_binaries import manager as jb_manager
 from sahara.utils import api_validator as a
 
 CONF = cfg.CONF
 
 
 def is_internal_db_enabled():
-    if not CONF.edp_internal_db_enabled:
-        return False
-    return True
+    return 'internal-db' in jb_manager.JOB_BINARIES.get_job_binaries()
 
 
 def check_job_binary_internal(data, **kwargs):
     if not is_internal_db_enabled():
         raise e.BadJobBinaryInternalException(
             _("Sahara internal db is disabled for storing job binaries."))
-    if not (type(data) is str and len(data) > 0):
+    if not (isinstance(data, six.binary_type) and len(data) > 0):
         raise e.BadJobBinaryInternalException()
     if "name" in kwargs:
         name = kwargs["name"]
