@@ -13,7 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
+
 import six
 import testtools
 
@@ -143,7 +144,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_v_wrong_network(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "test-name",
@@ -157,23 +157,7 @@ class TestClusterCreateValidation(u.ValidationTestCase):
                                        "94ce-b6df85a68332 not found")
         )
 
-    def test_cluster_create_mixed_nova_neutron(self):
-        self._assert_create_object_validation(
-            data={
-                'name': "test-name",
-                'plugin_name': "fake",
-                'hadoop_version': "0.1",
-                'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
-                'neutron_management_network': '53a36917-ab9f-4589-'
-                                              '94ce-b6df85a68332'
-            },
-            bad_req_i=(1, 'INVALID_REFERENCE',
-                       "'neutron_management_network' field can't "
-                       "be used with 'use_neutron=False'")
-        )
-
     def test_cluster_create_v_missing_network(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "test-name",
@@ -214,7 +198,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         self._assert_cluster_configs_validation(True)
 
     def test_cluster_create_v_right_data(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -236,7 +219,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         self._assert_cluster_default_image_tags_validation()
 
     def test_cluster_create_security_groups(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -261,7 +243,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_missing_floating_pool(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -293,7 +274,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_with_proxy_gateway(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -326,7 +306,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_security_groups_by_ids(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -351,7 +330,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_missing_security_groups(self):
-        self.override_config("use_neutron", True)
         self._assert_create_object_validation(
             data={
                 'name': "testname",
@@ -378,7 +356,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_availability_zone(self):
-        self.override_config('use_neutron', True)
         self._assert_create_object_validation(
             data={
                 'name': 'testname',
@@ -407,7 +384,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_wrong_availability_zone(self):
-        self.override_config('use_neutron', True)
         self._assert_create_object_validation(
             data={
                 'name': 'testname',
@@ -435,7 +411,6 @@ class TestClusterCreateValidation(u.ValidationTestCase):
         )
 
     def test_cluster_create_wrong_volumes_availability_zone(self):
-        self.override_config('use_neutron', True)
         self._assert_create_object_validation(
             data={
                 'name': 'testname',
@@ -532,6 +507,8 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             "plugin_name": "fake",
             "hadoop_version": "0.1",
             "cluster_template_id": '%s' % ctmpl_id,
+            "neutron_management_network": "d9a3bebc-f788-4b81-"
+                                          "9a93-aa048022c1ca",
             'default_image_id': '550e8400-e29b-41d4-a716-446655440000'
         }
         patchers = u.start_patch(False)
@@ -542,6 +519,8 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             "name": "testwithnodegroups",
             "plugin_name": "fake",
             "hadoop_version": "0.1",
+            "neutron_management_network": "d9a3bebc-f788-4b81-"
+                                          "9a93-aa048022c1ca",
             "node_groups": [
                 {
                     "name": "allinone",
@@ -576,6 +555,8 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             "name": "testwithnodegroups",
             "plugin_name": "fake",
             "hadoop_version": "0.1",
+            "neutron_management_network": "d9a3bebc-f788-4b81-"
+                                          "9a93-aa048022c1ca",
             "node_groups": [
                 {
                     "name": "allinone",
@@ -614,6 +595,8 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             "plugin_name": "fake",
             "hadoop_version": "0.1",
             "cluster_template_id": '%s' % ctmpl_id,
+            "neutron_management_network": "d9a3bebc-f788-4b81-"
+                                          "9a93-aa048022c1ca",
             'default_image_id': '550e8400-e29b-41d4-a716-446655440000',
             "node_groups": [
                 {
@@ -639,6 +622,8 @@ class TestClusterCreateFlavorValidation(base.SaharaWithDbTestCase):
             "name": "testtmplnodegroups",
             "plugin_name": "fake",
             "hadoop_version": "0.1",
+            "neutron_management_network": "d9a3bebc-f788-4b81-"
+                                          "9a93-aa048022c1ca",
             "node_groups": [
                 {
                     "node_group_template_id": '%s' % ng_id,
