@@ -13,11 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
 import testtools
+from unittest import mock
 
 from sahara import exceptions as ex
+from sahara.service import validation as v
 from sahara.service.validations import clusters as c_val
+from sahara.service.validations import clusters_schema as c_schema
 from sahara.tests.unit.service.validation import utils as u
 from sahara.tests.unit import testutils as tu
 
@@ -52,3 +54,34 @@ class TestClusterDeleteValidation(u.ValidationTestCase):
             except ex.DeletionFailed as e:
                 self.assert_created_in_another_tenant_exception(e)
                 raise e
+
+
+class TestClusterDeleteValidationV2(testtools.TestCase):
+    @mock.patch("sahara.utils.api.request_data")
+    @mock.patch("sahara.utils.api.bad_request")
+    def _validate_body(self, request, br, rd):
+        m_func = mock.Mock()
+        m_func.__name__ = "m_func"
+
+        rd.return_value = request
+
+        validator = v.validate(c_schema.CLUSTER_DELETE_SCHEMA_V2, m_func)
+        validator(m_func)(data=request)
+
+        return not br.call_count
+
+    def test_delete_schema_empty_body(self):
+        request = {}
+        self.assertTrue(self._validate_body(request))
+
+    def test_delete_schema_wrong_type(self):
+        request = {"force": "True"}
+        self.assertFalse(self._validate_body(request))
+
+    def test_delete_schema_extra_fields(self):
+        request = {"force": True, "just_kidding": False}
+        self.assertFalse(self._validate_body(request))
+
+    def test_delete_schema_good(self):
+        request = {"force": True}
+        self.assertTrue(self._validate_body(request))
